---
jupyter:
  kernelspec:
    display_name: Python 3
    language: python
    name: python3
  nbformat: 4
  nbformat_minor: 2
---

::: {#cell-1 .cell .code}
``` python
1+2+3
```
:::

::: {.cell .raw}
```{=ipynb}
This is a raw cell
```
:::

::: {.cell .markdown}
This is a markdown cell
:::
